#!/bin/sh

################################################################################
# Title: [Synapse ]HXD find script
# Date Created: September 9, 2001
# Time Created: 3:58 PM
# Author: Devin Teske
#
# Note: this script works with both HXD and SynHXD (aka. shxd)
#
# Requirements: these items must be installed and functioning
#	/usr/bin/find
#	sed
#	grep
#
# sed and grep must be in the execution path of the shell run on
#
# Info: this script is intended for use with GNU find 4.1
# I have made a binary that you can simply download and install for Mac OS X.
# The find utility on Mac OS X is deprecated and does not support the -iname or
# -printf flags to find. You have two options...
# 	option 1) you can change the line below to "deprecated_find=1;"
#			  and the this script will not perform case insensitive searching.
# 	option 2) you can download the premade binary and install it. It comes with
# 			  a very simple to understand readme file i made to guide you into
# 			  replacing the deprecated find. The tarball contains four files:
#			  the find binary, an install/uninstall script, and a readme.
#
# GNU find 4.1 for Mac OS X (darwin):
# 	http://synhxd.sourceforge.net/darwin_gnufind.tgz
################################################################################

####################### Configure Options

# change this to 1 if you have an old find binary
deprecated_find=0;

# change this to 1 to allow finding in drop boxes
read_dropboxes=0;

# change this to 1 to allow `/find *'
allow_all=0;

####################### Begin script

# read the number of arguments and find object
num=$#;
args=$@;

# check to see if `/find *' is allowed
if [ $allow_all == 0 ]; then
	# remove all the asterices to see if we have any content (since * is the
	# same as ** and *** and so on (which return all files).
	all=`echo "$args" | sed -e s/*//g`;

	if [ "$all" == "" -a "$args" != "" ]; then
		# this is output if the user attempts to list everything
		echo -n "
find: be more specific";
		exit 0;
	fi
fi

if [ $num == 0 -o "$args" == "" ]; then

	# this is output if the user hasn't supplied any arguments (ie. '/find')
	echo -n "
Usage: find <file name>";

else

	# the header is output at the beginning so the user knows it has started
	header="
Searching for \"$args\"...";
	echo -n "$header";

	if [ $deprecated_find == 0 ]; then

		# GNU find 4.1 recommended
		if [ $read_dropboxes == 1 ]; then
			# don't prune drop boxes
			find_result=`/usr/bin/find $ROOTDIR -follow -ipath '*/\.*' -prune -o -ipath '*/Network Trash Folder' -prune -o -ipath '*/TheVolumeSettingsFolder' -prune -o -ipath '*/TheFindByContentFolder' -prune -o -ipath '*/Icon
' -prune -o -iname "*$args*" -printf "\r   /%P"`;
		else
			# prune drop boxes (don't list items matching in drop boxes)
			find_result=`/usr/bin/find $ROOTDIR -follow -ipath '*/\.*' -prune -o -ipath '*/Network Trash Folder' -prune -o -ipath '*/TheVolumeSettingsFolder' -prune -o -ipath '*/TheFindByContentFolder' -prune -o -ipath '*/Icon
' -prune -o -ipath '*/*drop box*' -prune -o -iname "*$args*" -printf "\r   /%P"`;
		fi

	else

		# for older versions of find not supporting -iname or -printf
		# note, if you change the name of the folder that points to your files,
		# 	change the sed pipe too.
		# example: if you change your files folder in hxd.conf to ./software
		#	change "sed -e s/.*files/
\ /" to "sed -e s/.*software/
\ /"
		# it uses regular expressions, if you feel inclined, man awk
		find_result=`/usr/bin/find $ROOTDIR -follow -name "*$args*" | sed -e s/.*files/
\ \ \ / | grep -iv ".*/\..*" | grep -iv ".*/Network Trash Folder" | grep -iv ".*/TheVolumeSettingsFolder" | grep -iv "TheFindByContentFolder" | grep -iv ".*/Icon
"`;

		if [ $read_dropboxes == 0 ]; then
			# prune drop boxes (don't list items matching in drop boxes)
			find_result=`echo "$find_result" | grep -iv ".*/.*drop box.*"`;
		fi

	fi

	# the footer is output at the end so the user knows it's done
	footer="
done."

	if [ "$find_result" == "" ]; then
		# the script didn't find anything, but it's nice to say so
		echo -ne "\rNo Files Found";
	else
		# let's output what we found
		echo -n "$find_result";
	fi

	# tell the user that we are done by printing the footer
	echo -n "$footer";

fi
